# Welcome to Kaisia
## easy way to compare GBQ tables schemas right in your terminal
### Usage


```
bash$ pip install kaisia
...
bash$ kaisia
usage: kaisia [-h] [-V] [-t1 TABLE1] [-t2 TABLE2] [-c CREDENTIALS]

options:
  -h, --help            show this help message and exit
  -V, --version         show program's version number and exit
  -t1 TABLE1, --table1 TABLE1
                        Table1 full GBQ id
  -t2 TABLE2, --table2 TABLE2
                        Table2 full GBQ id
  -c CREDENTIALS, --credentials CREDENTIALS
                        GCP Service Account key
```
